/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2001.  All Rights Reserved.
 *
 * Protege-2000 was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu
 *
 * Contributor(s):
 */

package edu.stanford.smi.protege.model;

import java.util.*;

import edu.stanford.smi.protege.util.*;

/**
 * A constraint on the minimum number of values that a slot may contain.
 *
 * @author    Ray Fergerson <fergerson@smi.stanford.edu>
 */
public class MinimumCardinalityConstraint extends AbstractFacetConstraint {

    public String getInvalidValuesText(Frame frame, Slot slot, Collection slotValues, Collection facetValues) {
        String result = null;
        Integer i = (Integer) CollectionUtilities.getFirstItem(facetValues);
        if (i != null) {
            int min = i.intValue();
            if (slotValues.size() < min) {
                if (min == 1) {
                    result = "A value is required";
                } else {
                    result = "At least " + min + " values are required";
                }
            }
        }
        return result;
    }

    public String getInvalidValueText(Frame frame, Slot slot, Object o, Collection facetValues) {
        return null;
    }
    public static int getValue(Integer i) {
        return (i == null) ? 0 : i.intValue();
    }
    public static Integer getValue(int i) {
        return (i == 0) ? null : new Integer(i);
    }
    public Collection resolve(Collection existingValues, Collection newValues) {
        // higher value wins
        int i1 = getValue(existingValues);
        int i2 = getValue(newValues);
        return i1 >= i2 ? existingValues : newValues;
    }

    private int getValue(Collection values) {
        Integer i = (Integer) CollectionUtilities.getFirstItem(values);
        return (i == null) ? Integer.MIN_VALUE : i.intValue();
    }
}
