/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2001.  All Rights Reserved.
 *
 * Protege-2000 was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu
 *
 * Contributor(s):
 */

package edu.stanford.smi.protege.util;

import java.awt.*;
import java.util.*;

import javax.swing.*;

/**
 * A component that behaves like a tool bar but isn't one.  This component makes up for some bad behavior that I
 * experienced using the real toolbar in some circumtances.  Unfortunately I no longer remember what the behavior or
 * the circumstances were!  The problem may have been that it was very difficult to control the size of buttons on a
 * real toolbar.  This class should probably be removed and replaced with a real toolbar to see what, if any, problems
 * occur.  The original problems occured in JDK 1.2.
 *
 * @author    Ray Fergerson <fergerson@smi.stanford.edu>
 * @author    Holger Knublauch <holger@smi.stanford.edu>    (added separators)
 */
public class FakeToolBar extends JComponent {
    private JComponent _buttons;
    private Dimension _defaultButtonSize;

    public FakeToolBar(int justification) {
        this(justification, ComponentFactory.STANDARD_BUTTON_SIZE);
    }

    public FakeToolBar(int justification, Dimension buttonSize) {
        _defaultButtonSize = new Dimension(buttonSize);
        _buttons = new JPanel();
        _buttons.setOpaque(false);
        setLayout(new BorderLayout());
        String placement = (justification == SwingConstants.LEFT) ? BorderLayout.WEST : BorderLayout.EAST;
        add(_buttons, placement);
    }

    public JButton add(final Action action) {
        JButton button = ComponentFactory.addToolBarButton(this, action);
        button.setBackground(getBackground());
        return button;
    }

    public void addButton(AbstractButton button) {
        button.setPreferredSize(_defaultButtonSize);
        _buttons.add(button);
        updateLayout();
    }

    public void addSeparator() {
        addSeparator(4);
    }

    public void addSeparator(int width) {
        _buttons.add(Box.createHorizontalStrut(width));
        updateLayout();
    }

    public Collection getButtons() {
        Collection results = new ArrayList();
        Component[] comps = _buttons.getComponents();
        for (int i = 0; i < comps.length; i++) {
            Component comp = comps[i];
            if (comp instanceof AbstractButton) {
                results.add(comp);
            }
        }
        return results;
    }

    public void setEnabled(boolean b) {
        for (int i = 0; i < _buttons.getComponentCount(); ++i) {
            Component comp = _buttons.getComponent(i);
            comp.setEnabled(b);
        }
    }

    public void removeAllButtons() {
        _buttons.removeAll();
        updateLayout();
    }

    public void removeButton(int index) {
        _buttons.remove(index);
        updateLayout();
    }

    private void updateLayout() {
        _buttons.setLayout(new BoxLayout(_buttons, BoxLayout.X_AXIS));
        revalidate();
    }
}
