/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2001.  All Rights Reserved.
 *
 * Protege-2000 was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu
 *
 * Contributor(s):
 */

package edu.stanford.smi.protege.util;

/**
 * An interface that allows the implementer to veto a change or to record whatever is necessary when a save succeeds.
 *
 * @author Ray Fergerson <fergerson@smi.stanford.edu>
 */
public interface Validatable {

    /**
     * Save the contents of the current fields of this component to the
     * underlying data structure.  This method is called only after validateContents() has returned true for this 
     * object and, possibly, for other objects.
     */
    void saveContents();

    /**
     * Check whether the current values of the fields in this component are
     * valid. If they are, return true. If not, prompt the user with a dialog
     * explaining the problem and return false.
     */
    boolean validateContents();
}
